/* 
 * Copyright (c) 2008
 *     IS/AIST-ST2I/CNRS Joint Japanese-French Robotics Laboratory (JRL).
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#include <stdlib.h>
#include <err.h>

#include "viam_private.h"

/* --- local data ---------------------------------------------------- */

static void *	swap;		/**< temporary buffer for image filtering */
static size_t	swapsize;	/**< size of swap buffer */


/* --- viam_swap ----------------------------------------------------- */

/** \brief Get swap buffer
 *
 * \return A pointer on the swap buffer.
 */

void *
viam_swap()
{
  return swap;
}


/* --- viam_setswap -------------------------------------------------- */

/** \brief Allocate swap buffer
 *
 * \param[in] size	Required amount of swap space.
 *
 * \return A pointer on the swap buffer.
 */

void
viam_setswap(size_t size)
{
  if (size == 0) {
    if (swap) free(swap);
    swap = NULL;
    swapsize = 0;
    return;
  }
  if (size <= swapsize) return;

  if (swap) free(swap);
  swap = malloc(size);
  swapsize = size;
  if (!swap) {
    warnx("cannot allocate %d bytes for camera swap", size);
    swapsize = 0;
  }

  warnx("%d bytes of swap space allocated for image filtering", swapsize);
}
